@@ -150,7 +150,7 @@ wrprGetGigEVisionAPI()
   \brief Wrapper to GigEVisionAPI function
   \param api
   \param eventHandler
-  \return true - succsess, else - false
+  \return true - success, else - false
   See \a wrprInitGigEVisionAPI, \a gige::IGigEVisionAPI
 
 */
@@ -294,11 +294,11 @@ class CvCaptureCAM_Giganetix : public CvCapture
 
     virtual bool open( int index );
     virtual void close();
-    virtual double getProperty(int) const;
-    virtual bool setProperty(int, double);
-    virtual bool grabFrame();
-    virtual IplImage* retrieveFrame(int);
-    virtual int getCaptureDomain()
+    virtual double getProperty(int) const CV_OVERRIDE;
+    virtual bool setProperty(int, double) CV_OVERRIDE;
+    virtual bool grabFrame() CV_OVERRIDE;
+    virtual IplImage* retrieveFrame(int) CV_OVERRIDE;
+    virtual int getCaptureDomain() CV_OVERRIDE
     {
         return CV_CAP_GIGANETIX;
     }
@@ -441,7 +441,7 @@ CvCaptureCAM_Giganetix::grabImage ()
     {
       gige::IImageInfo imageInfo;
       m_device->GetImageInfo (&imageInfo);
-      assert(imageInfo.IsValid());
+      CV_Assert(imageInfo.IsValid());
 
       if (m_device->GetPendingImagesCount() ==  1)
       {
